@@ -4,7 +4,7 @@ from typing import Any
 
 from sinai import BaseView
 from sinai.adaptors import Memory
-from sinai.types import JDict, MetricList
+from sinai.types import JDict, MetricList, NullableBool
 
 
 class Source(BaseView):
@@ -25,11 +25,12 @@ class MetricSource(Source, Memory):
         name: str = "",
         ref: str = "",
         value: str = "",
+        checked: NullableBool = None,
         context: str = "",
         monitor_id: str = "",
     ) -> MetricList:
         """Get a metric/metrics from the Source"""
-        metric_filter = {}
+        metric_filter: JDict = {}
         if name:
             metric_filter["name"] = name
         if ref:
@@ -38,6 +39,8 @@ class MetricSource(Source, Memory):
             metric_filter["value"] = value
         if context:
             metric_filter["context"] = context
+        if checked is not None:
+            metric_filter["checked"] = checked
         if monitor_id:
             metric_filter["monitor_id"] = monitor_id
         return self._execute_query(metric_filter)
