@@ -15,7 +15,7 @@ else:
     HAS_BOTO = True
 
 from sinai.exceptions import DependencyMissing
-from sinai.stores import Store
+from sinai.stores.base import Store
 from sinai.types import MetricInstance, MonitorInstance
 
 
